@@ -12,15 +12,6 @@ from netbox_storage.models import Drive
 class DriveBaseTable(NetBoxTable):
     """Base class for tables displaying Drives"""
 
-    identifier = tables.Column(
-        linkify=True
-    )
-    size = tables.Column(
-        linkify=True
-    )
-    cluster = tables.Column(
-        linkify=True
-    )
 
 
 class DriveTable(DriveBaseTable):
@@ -30,6 +21,15 @@ class DriveTable(DriveBaseTable):
     virtual_machine = tables.Column(
         linkify=True
     )
+    identifier = tables.Column(
+        linkify=True
+    )
+    size = tables.Column(
+        linkify=True
+    )
+    cluster = tables.Column(
+        linkify=True
+    )
 
     class Meta(NetBoxTable.Meta):
         model = Drive
@@ -42,24 +42,8 @@ class DriveTable(DriveBaseTable):
             "description",
         )
         default_columns = (
+            "virtual_machine",
             "identifier",
-            "virtual_machine"
             "size",
             "cluster",
         )
-
-
-class RelatedDriveTable(DriveBaseTable):
-    actions = ActionsColumn(actions=())
-
-    class Meta(NetBoxTable.Meta):
-        model = Drive
-        fields = (
-            "size",
-            "cluster",
-        )
-        default_columns = (
-            "size",
-            "cluster",
-            "identifier",
-        )
